@@ -27,6 +27,7 @@ class ErrorInfo(Error):
     """
 
     code = 116
+    categories = ["builtin", "fstring"]
 
 
 FUNC_CONVERSIONS = {
@@ -49,6 +50,6 @@ def check(node: IndexExpr, errors: list[Error]) -> None:
                 ErrorInfo(
                     node.line,
                     node.column,
-                    f"Use `{fstring}` instead of `{name_node.name}(num)[2:]`",
+                    f"Replace `{name_node.name}(num)[2:]` with `{fstring}`",
                 )
             )
